==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/NativeUIDropDown.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { NativeUIComponent } from "./NativeUIComponent";
import { NativeUIDisplayDensity_$type } from "./NativeUIDisplayDensity";
import { enumGetBox, EnumUtil, markType } from "./type";
/**
 * @hidden
 */
export let NativeUIDropDown = /*@__PURE__*/ (() => {
    class NativeUIDropDown extends NativeUIComponent {
        constructor() {
            super(...arguments);
            this.au = null;
        }
        get_c() {
            return 4;
        }
        get at() {
            let a = this.o(1);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, a);
        }
        set at(a) {
            this.af(1, enumGetBox(NativeUIDisplayDensity_$type, a));
        }
        get av() {
            return this.au;
        }
        set av(a) {
            let b = this.au;
            this.au = a;
            if (this.au != null) {
                this.x(3, this.au);
            }
            else {
                this.ad(3, b);
            }
        }
        get ax() {
            let a = this.o(7);
            return a;
        }
        set ax(a) {
            this.af(7, a);
        }
        get aw() {
            let a = this.o(6);
            return a;
        }
        set aw(a) {
            this.af(6, a);
        }
    }
    NativeUIDropDown.$t = /*@__PURE__*/ markType(NativeUIDropDown, 'NativeUIDropDown', NativeUIComponent.$);
    return NativeUIDropDown;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/NativeUIDropDown.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { NativeUIComponent } from "./NativeUIComponent";
import { NativeUIDisplayDensity_$type } from "./NativeUIDisplayDensity";
import { enumGetBox, EnumUtil, markType } from "./type";
/**
 * @hidden
 */
export let NativeUIDropDown = /*@__PURE__*/ (() => {
    class NativeUIDropDown extends NativeUIComponent {
        constructor() {
            super(...arguments);
            this.az = null;
        }
        get_e() {
            return 4;
        }
        get ay() {
            let a = this.q(1);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, a);
        }
        set ay(a) {
            this.ak(1, enumGetBox(NativeUIDisplayDensity_$type, a));
        }
        get a0() {
            return this.az;
        }
        set a0(a) {
            let b = this.az;
            this.az = a;
            if (this.az != null) {
                this.z(3, this.az);
            }
            else {
                this.ai(3, b);
            }
        }
        get a2() {
            let a = this.q(7);
            return a;
        }
        set a2(a) {
            this.ak(7, a);
        }
        get a1() {
            let a = this.q(6);
            return a;
        }
        set a1(a) {
            this.ak(6, a);
        }
    }
    NativeUIDropDown.$t = /*@__PURE__*/ markType(NativeUIDropDown, 'NativeUIDropDown', NativeUIComponent.$);
    return NativeUIDropDown;
})();
